==> haskell-gridtables-0.1.0.0-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.0.0
visibility:           public
id:                   gridtables-0.1.0.0-A4um6mvxIEeCM7raMp0o7t
key:                  gridtables-0.1.0.0-A4um6mvxIEeCM7raMp0o7t
license:              MIT
copyright:            © 2022 RStudio, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  ebb1cedba74734db70c0f48bf01d678b
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.0.0-A4um6mvxIEeCM7raMp0o7t
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    doclayout-0.4.0.1-35fzgsndWSfH3Hy66Z8GTB parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gridtables-0.1.0.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.0.0
visibility:           public
id:                   gridtables-0.1.0.0-4Nx4Oaw31mYFDjoIAVTijm
key:                  gridtables-0.1.0.0-4Nx4Oaw31mYFDjoIAVTijm
license:              MIT
copyright:            © 2022 RStudio, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  57d4af78bf73dd309e8be250b305deaf
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.0.0-4Nx4Oaw31mYFDjoIAVTijm
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    doclayout-0.4.0.1-11YGqkWIg6qGXOFUIr62uJ parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
